<?php
// mysql_php_deletion.php
// Released on July 12, 2011
// Last update on July 23, 2011
// Author: Juan Valencia Escalante <contact@jveweb.net>
// For new versions visit:
// http://www.jveweb.net/en/archives/2011/07/prepared-mysql-statements-in-php-structured-examples.html

// This file shows the records in the database inside a table
//   and allow us to mark the records that we want to delete

header('Content-type: text/html; charset=utf8');

include_once('settings.php');

$message = "";

// Connect to the database
$link = mysqli_connect($mysql_host, $mysql_username, $mysql_password, $mysql_database);
if (!$link) {
    die("Can not connect to the database: " . mysqli_connect_error());
}

// Change character set to utf8
if (!mysqli_set_charset($link, "utf8")) {
    die("Error loading character set utf8: %s\n" . mysqli_error($link));
}

// Delete entries if the corresponding checkbox is marked
if (isset($_POST["cb"])) {

    // If we did receive an array of marked checkboxes, prepare the
    //   MySQL statement to delete the selected items
    if ($stmt = mysqli_prepare($link, "delete from `jveweb_net_test_table` where `field_id`=?")) {
        mysqli_stmt_bind_param($stmt, "d", $tmp_id);

        // Execute the query, moving to $tmp_id the value of $idadmin every iteration
        $deleted_records = 0;
        foreach ($_POST["cb"] as $id_admin => $value) {
                $tmp_id = $id_admin;
                mysqli_stmt_execute($stmt);
                $deleted_records += mysqli_stmt_affected_rows($stmt);
            }
        
            if ($deleted_records == 1) {
                $message = "<p><b>1 record was deleted</b></p>";
        } else {
            $message = "<p><b>$deleted_records records were deleted</b></p>";
        }

        // Close the statement
        mysqli_stmt_close($stmt);
    }
}

// Show the database entries in a table
$displayed_records = 0;
$query = "select * from `jveweb_net_test_table`";
$table = <<<THETABLE
<table cellspacing="0" summary="The results of a simple select query">
    <caption>List of records in the database</caption>
    <thead>
        <tr>
            <th>&nbsp;</th>
            <th scope="col">field_id</th>
            <th scope="col">field_name</th>
            <th scope="col">field_address</th>
            <th scope="col">field_email</th>
            <th scope="col">field_created</th>
            <th scope="col">field_modified</th>
        </tr>
    </thead>
    <tbody>
THETABLE;

$result = mysqli_query($link, $query);
if ($result) {
    while ($row = mysqli_fetch_assoc($result)) {

        $table .= <<<THETABLE
        <tr>
            <td><input type="checkbox" name="cb[{$row["field_id"]}]" /></td>
            <td>{$row["field_id"]}</th>
            <td>{$row["field_name"]}</td>
            <td>{$row["field_address"]}</td>
            <td>{$row["field_email"]}</td>
            <td>{$row["field_created"]}</td>
            <td>{$row["field_modified"]}</td>
        </tr>
THETABLE;

        $displayed_records++;
    }    
}

// If nothing was found in the table, create a row with an error message
if ($displayed_records == 0) {
    $table .= <<<THETABLE
        <tr>
            <td colspan="7">The table is empty</td>
        </tr>
THETABLE;
}

$table .= "    </tbody>\n</table>";

// Close  the MySQL connection
mysqli_close($link);

?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"> 
<html xmlns="http://www.w3.org/1999/xhtml"> 
<head> 
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /> 
    <meta name="keywords" content="" /> 
    <meta name="description" content="" /> 
    <meta name="author" content="Juan Valencia Escalante" /> 
    <title>MySQL/PHP Deletion example - Juan Valencia's website - jveweb.net</title> 
    <style type="text/css">
        table {
            background:#FFF;
            border:1px solid #CCC;
            margin:5px 0 10px;
        }
        table tr td {
            border-top:1px solid #CCC;
            padding:2px 10px;
        }
        table tr th {
            padding:1px 10px;
            background:#EDEFF0;
            text-align:left;
        }
    </style>
</head> 
<body> 
    <div id="content"> 
        <form action="mysql_php_deletion.php" method="post">
    <?=$table;?>
            <input type="submit" />
        </form>
        <?=$message;?>
        <p>
            <a href="mysql_php_show.php">Show the records</a><br />
            <a href="mysql_php_insertion.php">Insert a new record</a><br />
            <a href="mysql_php_create_table.php?reset=1">Reset the table</a>
        </p>
    </div> 
</body> 
</html>
