<?php
// mysql_php_insertion.php
// Released on July 12, 2011
// Last update on July 23, 2011
// Author: Juan Valencia Escalante <contact@jveweb.net>
// For new versions visit:
// http://www.jveweb.net/en/archives/2011/07/prepared-mysql-statements-in-php-structured-examples.html

// This file adds a record to the database
// Upon success it shows the ID of the record and gives the option to edit it

header('Content-type: text/html; charset=utf8');

include_once('settings.php');

$message = "";

// If we receive any data, store it in a new record
if ($_POST["name"]!="" || $_POST["address"]!="" || $_POST["email"]!="") {

    $last_id = 0;

    // Some basic XSS prevention
    // Strip the html tags to prevent XSS attacks when you display the
    //   information inside other elements
    // In adition, if you are going to put text into the value attribute
    //   of an input element, and you use double quotes as delimiters, then
    //   also strip the double quotes of this fields, the same goes for
    //   single quotes
    $tmp_name = strip_tags($_POST["name"]);
    $tmp_address = strip_tags($_POST["address"]);
    $tmp_email = strip_tags($_POST["email"]);
    $tmp_name = str_replace('"', '', $tmp_name);
    $tmp_address = str_replace('"', '', $tmp_address);
    $tmp_email = str_replace('"', '', $tmp_email);

    // Connect to the database
    $link = mysqli_connect($mysql_host, $mysql_username, $mysql_password, $mysql_database);
    if (!$link) {
        die("Can not connect to the database: " . mysqli_connect_error());
    }

    // Change character set to utf8
    if (!mysqli_set_charset($link, "utf8")) {
        die("Error loading character set utf8: %s\n" . mysqli_error($link));
    }
    
    // Create the prepared MySQL statement, bind the variables and execute it
    if ($stmt = mysqli_prepare($link, "insert into `jveweb_net_test_table`
    (`field_name`, `field_address`, `field_email`, `field_created`)
    values(?,?,?,NOW())")) {
        mysqli_stmt_bind_param($stmt, 'sss', $tmp_name, $tmp_address, $tmp_email);
        mysqli_stmt_execute($stmt);

        // Obtain the last inserted  ID
        $last_id = mysqli_insert_id($link);
        if ($last_id != 0) {
            $message = "<b>Record successfully inserted<br />\n
                        The ID of the last inserted record is: $last_id</b><br />\n
                        </p><p>\n
                        <a href=\"mysql_php_edition.php?id=$last_id\">Edit the last inserted record</a><br />\n";
        }

        // Close the prepared MySQL statement
        mysqli_stmt_close($stmt);
    }

    // Close  the MySQL connection
    mysqli_close($link);
}
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"> 
<html xmlns="http://www.w3.org/1999/xhtml"> 
<head> 
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /> 
    <meta name="keywords" content="" /> 
    <meta name="description" content="" /> 
    <meta name="author" content="Juan Valencia Escalante" /> 
    <title>MySQL/PHP Insertion example - Juan Valencia's website - jveweb.net</title> 
    <style type="text/css">
        form {
            width:330px;
        }
        label {
            float:left;
            width:80px;
            text-align:right;
            padding-right:5px;
            clear:left;
        }
        input {
            float:left;
            width:200px;
        }
        .button {
            width:100px;
        }
    </style>
</head> 
<body> 
    <div id="content"> 
        <form action="mysql_php_insertion.php" method="post" accept-charset="utf-8">
            <fieldset>
                <legend>A simple form for insertion</legend>
                <label for"name">Name:</label>
                <input type="text" name="name" id="name" tabindex="1" /><br />
                <label for="address">Address:</label>
                <input type="text" name="address" id="address" tabindex="2" /><br />
                <label for="email">E-mail:</label>
                <input type="text" name="email" id="email" tabindex="3" /><br />
                <input type="submit" class="button" tabindex="4" />
            </fieldset>
        </form>
        <p>
            <?=$message;?>
            <a href="mysql_php_show.php">Show a list of the records</a><br />
            <a href="mysql_php_deletion.php">Delete records</a><br />
            <a href="mysql_php_create_table.php?reset=1">Reset the table</a>
        </p>
    </div> 
</body> 
</html>
